unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VCLTee.TeEngine, VCLTee.Series,
  Vcl.ExtCtrls, VCLTee.TeeProcs, VCLTee.Chart, Vcl.StdCtrls,
  VCLTee.TeeExtraLegendTool;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Series1: TBarSeries;
    Series2: TBarSeries;
    Series3: TBarSeries;
    Series4: TBarSeries;
    Series5: TBarSeries;
    Series6: TBarSeries;
    Button1: TButton;
  private
    FExtraLegend: TExtraLegendTool;
    procedure DrawSymbol(Sender: TObject; Series: TChartSeries; ValueIndex: Integer; aR: TRect);
  public
    { Public declarations }
    constructor Create(aO: TComponent); override;
  end;

var
  Form1: TForm1;

implementation

uses
  VCLTee.TeCanvas;

{$R *.dfm}

{ TForm1 }

procedure GenrateColorArray(const aColor1, aColor2: TColor; var aCOlorArray: array of TColor);
var
  I: Integer;
  lR, lG, lB: word;
  lCount: integer;
  lRDiff, lGDiff, lBDiff: double;
begin

  lR := GetRValue(aColor1);
  lG := GetGValue(aColor1);
  lB := GetBValue(aColor1);

  lCount := Length(aCOlorArray);

  lRDiff := (GetRValue(aColor2) - lR) / lCount;
  lGDiff := (GetGValue(aColor2) - lG) / lCount;
  lBDiff := (GetBValue(aColor2) - lB) / lCount;

  aColorArray[Low(aColorArray)] := aColor1;
  aColorArray[High(aColorArray)] := aColor2;

  for I := (Low(aColorArray) + 1) to (High(aColorArray) - 1) do
    aColorArray[I] := RGB(lR + Round(lRDiff * I), lG + Round(lGDiff * I), lB + Round(lBDiff * I));
end;

function GetColorSawpGB(const aColor: TColor): TColor;
begin
  result := RGB(GetRValue(aColor), GetBValue(aColor), GetGValue(aColor));
end;


constructor TForm1.Create(aO: TComponent);
var
  lItem: TLegendItem;
  lColor1: TColor;
  lColor2: TColor;
  lColors: array of TColor;
begin
  inherited;

  lColor1 := $00FFDFBF;
  lColor2 :=  $00885B00;

  SetLength(lColors, 3);

  GenrateColorArray(lColor1, lColor2, lColors);

  Series1.Color := lColors[0];
  Series2.Color := GetColorSawpGB(Series1.Color);
  Series2.ShowInLegend := False;

  Series3.Color := lColors[1];
  Series4.Color := GetColorSawpGB(Series3.Color);
  Series4.ShowInLegend := False;

  Series5.Color := lColors[2];
  Series6.Color := GetColorSawpGB(Series5.Color);
  Series6.ShowInLegend := False;

  Series1.FillSampleValues(10);
  Series2.FillSampleValues(10);
  Series3.FillSampleValues(10);
  Series4.FillSampleValues(10);
  Series5.FillSampleValues(10);
  Series6.FillSampleValues(10);

  Chart1.Legend.Symbol.OnDraw := DrawSymbol;



  FExtraLegend := TExtraLegendTool.Create(self);
  FExtraLegend.ParentChart := Chart1;
  FExtraLegend.Legend.CustomPosition := True;
  FExtraLegend.Legend.Left := 50;
  FExtraLegend.Legend.Top := 50;
  FExtraLegend.Legend.LegendStyle := lsAuto;
  FExtraLegend.Legend.Transparent := True;
  FExtraLegend.Series := Series1;
  FExtraLegend.Active := True;
  FExtraLegend.Legend.Symbol.Width := 45;

  lItem := TLegendItem.Create;
  lItem.Text := 'Pre-Tax';
  FExtraLegend.Legend.Items.Add(lItem);

  lItem := TLegendItem.Create;
  lItem.Text := 'Roth';
  FExtraLegend.Legend.Items.Add(lItem);
end;

procedure TForm1.DrawSymbol(Sender: TObject; Series: TChartSeries;
  ValueIndex: Integer; aR: TRect);
var
  lCanvas: TCanvas3D;
  lR: TRect;
  lColor: TColor;
begin
  lCanvas := Series.ParentChart.Canvas;
  lColor := Series.Color;

  lCanvas.Brush.Color := lColor;
  lCanvas.Pen.Color := lColor;

  lR := Rect(aR.Left, aR.Top, aR.Left + aR.Height, aR.Top + aR.Height);
  lCanvas.FillRect(lR);


  lColor := GetColorSawpGB(lColor);

  lR := Rect(aR.Left + aR.Width - aR.Height, aR.Top, aR.Left + aR.Width, aR.Top + aR.Height);
  lCanvas.Brush.Color := lColor;
  lCanvas.Pen.Color := lColor;
  lCanvas.FillRect(lR);

  Series.Color;
end;

end.
